@@ -1,9 +1,10 @@
+import os
 import tkinter as tk
 from tkinter import font  as tkfont
 from tkinter import filedialog
 from tkinter import ttk
 from tkinter import *
-from vars import getGlobalVariables
+from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
 
 
@@ -54,9 +55,7 @@ class ChooseGeneralExperiment(tk.Frame):
     tk.Label(self, text="").pack()
     
     drosophilia = IntVar()
-    # Checkbutton(self, text="Drosophilia", variable=drosophilia).pack()
     rodent = IntVar()
-    # Checkbutton(self, text="Mouse / Rodent", variable=rodent).pack()
     other = IntVar()
     Checkbutton(self, text="Track centers of mass of any kind of animal.", variable=other).pack()
     tk.Label(self, text='Several animals can be tracked at once. The animals must be "darker" than the background and the background must be still.').pack()
@@ -80,20 +79,22 @@ class WellOrganisation(tk.Frame):
     
     circular = IntVar()
     Checkbutton(self, text="Circular Wells", variable=circular).pack()
-    # rectangular = IntVar()
-    # Checkbutton(self, text="Rectangular Wells", variable=rectangular).pack()
+    
+    rectangular = IntVar()
+    Checkbutton(self, text="Rectangular Wells", variable=rectangular).pack()
+    
     roi = IntVar()
     Checkbutton(self, text="Choose Region of Interest", variable=roi).pack()
     other = IntVar()
     Checkbutton(self, text="Whole video", variable=other).pack()
     
     
-    tk.Button(self, text="Next", command=lambda: controller.wellOrganisation(controller, circular.get(), roi.get(), other.get())).pack()
+    tk.Button(self, text="Next", command=lambda: controller.wellOrganisation(controller, circular.get(), rectangular.get(), roi.get(), other.get())).pack()
     
     tk.Button(self, text="Go to the start page", command=lambda: controller.show_frame("StartPage")).pack()
 
 
-class CircularWells(tk.Frame):
+class CircularOrRectangularWells(tk.Frame):
 
   def __init__(self, parent, controller):
   
@@ -114,7 +115,7 @@ class CircularWells(tk.Frame):
     nbWellsPerRows = tk.Entry(self)
     nbWellsPerRows.pack()
     
-    tk.Button(self, text="Next", command=lambda: controller.circularWells(controller, nbwells.get(), nbRowsOfWells.get(), nbWellsPerRows.get())).pack()
+    tk.Button(self, text="Next", command=lambda: controller.circularOrRectangularWells(controller, nbwells.get(), nbRowsOfWells.get(), nbWellsPerRows.get())).pack()
     
     tk.Button(self, text="Go to the start page", command=lambda: controller.show_frame("StartPage")).pack()
 
@@ -134,7 +135,8 @@ class ChooseCircularWellsLeft(tk.Frame):
     
     canvas = Canvas(self, width=2500, height=2000)
     canvas.pack()
-    img = PhotoImage(file="./code/GUI/leftborder.png")
+    cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+    img = PhotoImage(file=os.path.join(cur_dir_path, 'leftborder.png'))
     self.img = img
     canvas.create_image(20, 20, anchor=NW, image=img)
     
@@ -156,7 +158,8 @@ class ChooseCircularWellsRight(tk.Frame):
     
     canvas = Canvas(self, width=2500, height=2000)
     canvas.pack()
-    img = PhotoImage(file="./code/GUI/rightborder.png")
+    cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+    img = PhotoImage(file=os.path.join(cur_dir_path, 'rightborder.png'))
     self.img = img
     canvas.create_image(20, 20, anchor=NW, image=img)
     
@@ -212,7 +215,8 @@ class IdentifyHeadCenter(tk.Frame):
     
     canvas = Canvas(self, width=2500, height=2000)
     canvas.pack()
-    img = PhotoImage(file="./code/GUI/blobCenter.png")
+    cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+    img = PhotoImage(file=os.path.join(cur_dir_path, 'blobCenter.png'))
     self.img = img
     canvas.create_image(20, 20, anchor=NW, image=img)
     
@@ -234,7 +238,8 @@ class IdentifyBodyExtremity(tk.Frame):
     
     canvas = Canvas(self, width=2500, height=2000)
     canvas.pack()
-    img = PhotoImage(file="./code/GUI/blobExtremity.png")
+    cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+    img = PhotoImage(file=os.path.join(cur_dir_path, 'blobExtremity.png'))
     self.img = img
     canvas.create_image(20, 20, anchor=NW, image=img)
     
