@@ -1,3 +1,4 @@
+from pathlib import Path
 import numpy as np
 import tkinter as tk
 from tkinter import font  as tkfont
@@ -6,25 +7,45 @@ from tkinter import ttk
 from tkinter import *
 import json
 import cv2
-from getCoordinates import findWellLeft, findWellRight, findHeadCenter, findBodyExtremity
+from zebrazoom.code.GUI.getCoordinates import findWellLeft, findWellRight, findHeadCenter, findBodyExtremity
 import math
-from findWells import findWells
-from getHyperparameters import getHyperparametersSimple
-from getBackground import getBackground
-from getForegroundImage import getForegroundImage
+from zebrazoom.code.findWells import findWells
+from zebrazoom.code.getHyperparameters import getHyperparametersSimple
+from zebrazoom.code.getBackground import getBackground
+from zebrazoom.code.getImage.getForegroundImage import getForegroundImage
 import cvui
-from vars import getGlobalVariables
+import pickle
+from zebrazoom.code.vars import getGlobalVariables
+from zebrazoom.mainZZ import mainZZ
 import json
 import os
 globalVariables = getGlobalVariables()
 
+def getMainArguments(self):
+  s            = self.videoToCreateConfigFileFor
+  arr          = s.split("/")
+  nameWithExt  = arr.pop()
+  pathToVideo  = '/'.join(arr) + '/'
+  nameWithExtL = nameWithExt.split(".")
+  videoExt     = nameWithExtL.pop()
+  videoName    = '.'.join(nameWithExtL)
+  configFile   = self.configFile
+  argv         = []
+  return [pathToVideo, videoName, videoExt, configFile, argv]
+
 def chooseVideoToCreateConfigFileFor(self, controller, reloadConfigFile):
 
   if int(reloadConfigFile):
+  
+    cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+    pathconf = Path(cur_dir_path)
+    pathconf = pathconf.parent.parent
+    pathconf = os.path.join(pathconf, 'configuration/')
+    
     if globalVariables["mac"]:
-      configFileName =  filedialog.askopenfilename(initialdir = "./configuration/",title = "Select file")
+      configFileName =  filedialog.askopenfilename(initialdir = pathconf, title = "Select file")
     else:
-      configFileName =  filedialog.askopenfilename(initialdir = "./configuration/",title = "Select file",filetypes = (("json files","*.json"),("all files","*.*")))
+      configFileName =  filedialog.askopenfilename(initialdir = pathconf, title = "Select file", filetypes = (("json files","*.json"),("all files","*.*")))
     with open(configFileName) as f:
       self.configFile = json.load(f)
 
@@ -50,45 +71,78 @@ def chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophil
     self.configFile["freeSwimmingTailTrackingMethod"] = "none"
     controller.show_frame("WellOrganisation")
 
-def wellOrganisation(self, controller, circular, roi, other):
-  if circular and self.organism != 'drosoorrodent':
-    controller.show_frame("CircularWells")
+def wellOrganisation(self, controller, circular, rectangular, roi, other):
+  if rectangular:
+    self.shape = 'rectangular'
+    self.configFile["wellsAreRectangles"] = 1
+    controller.show_frame("CircularOrRectangularWells")
   else:
-    if roi:
-      cap = cv2.VideoCapture(self.videoToCreateConfigFileFor)
-      cap.set(1, 10)
-      ret, frame = cap.read()
-      
-      WINDOW_NAME = "Click on the top left of the region of interest"
-      cvui.init(WINDOW_NAME)
-      cv2.moveWindow(WINDOW_NAME, 0,0)
-      cvui.imshow(WINDOW_NAME, frame)
-      while not(cvui.mouse(cvui.CLICK)):
-        cursor = cvui.mouse()
-        if cv2.waitKey(20) == 27:
-          break
-      self.configFile["oneWellManuallyChosenTopLeft"] = [cursor.x, cursor.y]
-      cv2.destroyAllWindows()
-      
-      WINDOW_NAME = "Click on the bottom right of the region of interest"
-      cvui.init(WINDOW_NAME)
-      cv2.moveWindow(WINDOW_NAME, 0,0)
-      cvui.imshow(WINDOW_NAME, frame)
-      while not(cvui.mouse(cvui.CLICK)):
-        cursor = cvui.mouse()
-        if cv2.waitKey(20) == 27:
-          break
-      self.configFile["oneWellManuallyChosenBottomRight"] = [cursor.x, cursor.y]
-      cv2.destroyAllWindows()
-      
-      self.configFile["nbWells"] = 1
-      chooseBeginningAndEndOfVideo(self, controller)
+    if circular and self.organism != 'drosoorrodent': # should remove the self.organism != 'drosoorrodent' at some point
+      self.shape = 'circular'
+      controller.show_frame("CircularOrRectangularWells")
     else:
-      self.configFile["noWellDetection"] = 1
-      self.configFile["nbWells"] = 1
-      chooseBeginningAndEndOfVideo(self, controller)
+      self.shape = 'other'
+      if roi:
+        cap = cv2.VideoCapture(self.videoToCreateConfigFileFor)
+        cap.set(1, 10)
+        ret, frame = cap.read()
+        
+        WINDOW_NAME = "Click on the top left of the region of interest"
+        cvui.init(WINDOW_NAME)
+        cv2.moveWindow(WINDOW_NAME, 0,0)
+        cvui.imshow(WINDOW_NAME, frame)
+        while not(cvui.mouse(cvui.CLICK)):
+          cursor = cvui.mouse()
+          if cv2.waitKey(20) == 27:
+            break
+        self.configFile["oneWellManuallyChosenTopLeft"] = [cursor.x, cursor.y]
+        cv2.destroyAllWindows()
+        
+        WINDOW_NAME = "Click on the bottom right of the region of interest"
+        cvui.init(WINDOW_NAME)
+        cv2.moveWindow(WINDOW_NAME, 0,0)
+        cvui.imshow(WINDOW_NAME, frame)
+        while not(cvui.mouse(cvui.CLICK)):
+          cursor = cvui.mouse()
+          if cv2.waitKey(20) == 27:
+            break
+        self.configFile["oneWellManuallyChosenBottomRight"] = [cursor.x, cursor.y]
+        cv2.destroyAllWindows()
+        
+        self.configFile["nbWells"] = 1
+        chooseBeginningAndEndOfVideo(self, controller)
+      else:
+        self.configFile["noWellDetection"] = 1
+        self.configFile["nbWells"] = 1
+        chooseBeginningAndEndOfVideo(self, controller)
 
-def circularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
+
+def rectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
+  
+  [pathToVideo, videoName, videoExt, configFile, argv] = getMainArguments(self)
+  
+  configFile["adjustRectangularWellsDetect"] = 1
+  
+  try:
+    WINDOW_NAME = "Please Wait"
+    cvui.init(WINDOW_NAME)
+    cv2.moveWindow(WINDOW_NAME, 0,0)
+    r = cv2.waitKey(2)
+    mainZZ(pathToVideo, videoName, videoExt, configFile, argv)
+    cv2.destroyAllWindows()
+  except ValueError:
+    newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+    for index in newhyperparameters:
+      configFile[index] = newhyperparameters[index]
+  
+  configFile["adjustRectangularWellsDetect"] = 0
+  
+  self.configFile = configFile
+  
+  chooseBeginningAndEndOfVideo(self, controller)
+  
+
+def circularOrRectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
   self.configFile["nbWells"]        = int(nbwells)
   
   if len(nbRowsOfWells):
@@ -101,7 +155,11 @@ def circularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
   else:
     self.configFile["nbWellsPerRows"]  = 4
   
-  controller.show_frame("ChooseCircularWellsLeft")
+  if self.shape == 'circular':
+    controller.show_frame("ChooseCircularWellsLeft")
+  else:
+    rectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows)
+
 
 def chooseCircularWellsLeft(self, controller):
   cap = cv2.VideoCapture(self.videoToCreateConfigFileFor)
@@ -241,7 +299,9 @@ def chooseBeginningAndEndOfVideo(self, controller):
 
   
 def getImageForMultipleAnimalGUI(l, vertical, horizontal, nx, ny, max_l, videoToCreateConfigFileFor, background, wellPositions, hyperparameters):
-  frame = getForegroundImage(videoToCreateConfigFileFor, background, l, 0, wellPositions, hyperparameters)
+  
+  frame = getForegroundImage(videoToCreateConfigFileFor, background, l, 0, [], hyperparameters)
+  
   lengthX = nx * 2
   lengthY = ny
   
@@ -308,6 +368,9 @@ def printStuffOnCtrlImg(frameCtrl, frameNum, x, y, l, minn, maxx, name):
   cvui.counter(frameCtrl,  x+l+10, y+20,    frameNum)
 
 def identifyMultipleHead(self, controller, nbanimals):
+  
+  self.configFile["videoName"] = "configFilePrep"
+
   tempConfig = self.configFile
   
   horizontal = self.winfo_screenwidth()
@@ -315,6 +378,7 @@ def identifyMultipleHead(self, controller, nbanimals):
   
   # Wait image
   WINDOW_NAME = "Please Wait"
+  cv2.destroyAllWindows()
   cvui.init(WINDOW_NAME)
   cv2.moveWindow(WINDOW_NAME, 0,0)
   # Getting hyperparameters, wellPositions, and background
@@ -322,28 +386,43 @@ def identifyMultipleHead(self, controller, nbanimals):
   wellPositions = findWells(self.videoToCreateConfigFileFor, hyperparameters)
   background    = getBackground(self.videoToCreateConfigFileFor, hyperparameters)
   
+  cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+  cur_dir_path = Path(cur_dir_path)
+  
   tab = [1]
-  img = cv2.imread('./code/GUI/no1.png')
+  img = cv2.imread(os.path.join(cur_dir_path, 'no1.png'))
   img = cv2.resize(img,(int(horizontal*0.95),int(vertical*0.8)))
   buttonclicked = False
+  count = 0
   while not(buttonclicked):
     buttonclicked = cvui.button(img, 10, 10, "Ok, I understand!")
     cvui.imshow(WINDOW_NAME, img)
     cv2.waitKey(20)
-  img = cv2.imread('./code/GUI/no2.png')
+    count = count + 1
+    if count > 100:
+      buttonclicked = True
+  img = cv2.imread(os.path.join(cur_dir_path, 'no2.png'))
   img = cv2.resize(img,(int(horizontal*0.95),int(vertical*0.8)))
   buttonclicked = False
+  count = 0
   while not(buttonclicked):
     buttonclicked = cvui.button(img, 10, 10, "Ok, I understand!")
     cvui.imshow(WINDOW_NAME, img)
     cv2.waitKey(20)
-  img = cv2.imread('./code/GUI/ok1.png')
+    count = count + 1
+    if count > 100:
+      buttonclicked = True
+  img = cv2.imread(os.path.join(cur_dir_path, 'ok1.png'))
   img = cv2.resize(img,(int(horizontal*0.95),int(vertical*0.8)))
   buttonclicked = False
+  count = 0
   while not(buttonclicked):
     buttonclicked = cvui.button(img, 10, 10, "Ok, I understand!")
     cvui.imshow(WINDOW_NAME, img)
     cv2.waitKey(20)
+    count = count + 1
+    if count > 100:
+      buttonclicked = True
   
   WINDOW_NAME = "Adjust Parameters: As much as possible, you must see red points on and only on animals on the right image."
   WINDOW_NAME_CTRL = "Adjust Parameters."
@@ -354,7 +433,7 @@ def identifyMultipleHead(self, controller, nbanimals):
   ny         = int(cap.get(4))
   max_l      = int(cap.get(7))
   
-  hyperparameters["minArea"] = 10
+  hyperparameters["minArea"] = 5
   hyperparameters["maxArea"] = 800
 
   [frame, maxAreaBlobs] = getImageForMultipleAnimalGUI(1, vertical, horizontal, nx, ny, max_l, self.videoToCreateConfigFileFor, background, wellPositions, hyperparameters)
@@ -409,6 +488,8 @@ def identifyMultipleHead(self, controller, nbanimals):
         break
   cv2.destroyAllWindows()
   
+  del self.configFile["videoName"]
+  
   self.configFile["minPixelDiffForBackExtract"] = int(hyperparameters["minPixelDiffForBackExtract"])
   self.configFile["thresholdForBlobImg"]        = int(hyperparameters["thresholdForBlobImg"])
   self.configFile["dilateIter"]                 = int(hyperparameters["dilateIter"])
@@ -499,7 +580,13 @@ def goToAdvanceSettings(self, controller, yes, no):
     self.calculateBackgroundFreelySwim(controller, 0)
 
 def finishConfig(self, controller, configFileNameToSave):
-  with open('./configuration/' + configFileNameToSave + '.json', 'w') as outfile:
+
+  cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+  cur_dir_path = Path(cur_dir_path)
+  cur_dir_path = cur_dir_path.parent.parent
+  reference = os.path.join(cur_dir_path, os.path.join('configuration', configFileNameToSave + '.json'))
+
+  with open(reference, 'w') as outfile:
     json.dump(self.configFile, outfile)
   self.configFile = {}
   self.videoToCreateConfigFileFor = ''
