@@ -5,15 +5,16 @@ import math
 import json
 import os
 import sys
-import popUpAlgoFollow
+import zebrazoom.code.popUpAlgoFollow as popUpAlgoFollow
 import pandas as pd
+from scipy.interpolate import UnivariateSpline
 
 import numpy as np
 from filterpy.kalman import KalmanFilter
 from filterpy.common import Q_discrete_white_noise
 
-from detectMovementWithRawVideo import detectMovementWithRawVideo
-from getTailTipManual import getHeadPositionByFileSaved, getTailTipByFileSaved
+from zebrazoom.code.detectMovementWithRawVideo import detectMovementWithRawVideo
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.getTailTipManual import getHeadPositionByFileSaved, getTailTipByFileSaved
 
 import pdb
 
@@ -53,17 +54,50 @@ def calculateTailAngle(angle1, angle2):
   if output > 3.14159265:
     output = output - 2*3.14159265;
   return output
+  
+def smoothAllTailAngles(allAngles, hyperparameters, start, end):
+  tailangles_arr = np.transpose(allAngles[start:end+1, 1:len(allAngles)])
+  tailangles_arr_smoothed = np.zeros((0, len(tailangles_arr[0])))
+  for angle_raw in tailangles_arr:
+    rolling_window = hyperparameters["tailAngleMedianFilter"]
+    if rolling_window > 0:
+      shift = int(-rolling_window / 2)
+      angle_median = np.array(pd.Series(angle_raw).rolling(rolling_window).median())
+      angle_median = np.roll(angle_median, shift)
+      for ii in range(0, rolling_window):
+        if ii >= 0 and ii < len(angle_raw):
+          angle_median[ii] = angle_raw[ii]
+      for ii in range(len(angle_median)-rolling_window,len(angle_median)):
+        if ii >= 0 and ii < len(angle_raw):
+          angle_median[ii] = angle_raw[ii]
+    else:
+      angle_median = angle_raw
+    tailToSmooth = angle_median
+    if len(tailToSmooth) >= 5:
+      x = np.linspace(0, 1, len(tailToSmooth))
+      s = UnivariateSpline(x, tailToSmooth, s=hyperparameters["tailAngleSmoothingFactor"])
+      tailSmoothed     = s(x)
+    else:
+      tailSmoothed = tailToSmooth
+      
+    tailSmoothed2    = np.zeros((1, len(tailSmoothed)))
+    tailSmoothed2[0] = tailSmoothed
+      
+    tailangles_arr_smoothed = np.append(tailangles_arr_smoothed, tailSmoothed2, axis=0)
+  return [tailangles_arr, tailangles_arr_smoothed]
 
-def extractParameters(trackingData, wellNumber, hyperparameters, videoPath, wellPositions, background):
+def extractParameters(trackingData, wellNumber, hyperparameters, videoPath, wellPositions, background, tailAngle = 0):
 
   firstFrame = hyperparameters["firstFrame"]
   thresAngleBoutDetect = hyperparameters["thresAngleBoutDetect"]
   debugExtractParams = hyperparameters["debugExtractParams"]
+  tailAngleSmoothingFactor = hyperparameters["tailAngleSmoothingFactor"]
 
   trackingHeadTailAllAnimals = trackingData[0]
-  trackingHeadingAllAnimals = trackingData[1]
-  headPositionFirstFrame = trackingData[2]
-  tailTipFirstFrame = trackingData[3]
+  trackingHeadingAllAnimals  = trackingData[1]
+  trackingEyesAllAnimals     = trackingData[2]
+  headPositionFirstFrame     = trackingData[3]
+  tailTipFirstFrame          = trackingData[4]
   
   data = []
   
@@ -79,13 +113,14 @@ def extractParameters(trackingData, wellNumber, hyperparameters, videoPath, well
     nbFrames = len(trackingTail)
     nbPoints = len(trackingTail[0])
 
-    tail_1  = np.zeros((nbFrames, 2))
-    tip     = np.zeros((nbFrames, 2))
-    head    = np.zeros((nbFrames, 2))
-    heading = np.zeros((nbFrames, 1))
-    angle   = np.zeros((nbFrames, 1))
-    tailX   = np.zeros((nbFrames, n))
-    tailY   = np.zeros((nbFrames, n))
+    tail_1    = np.zeros((nbFrames, 2))
+    tip       = np.zeros((nbFrames, 2))
+    head      = np.zeros((nbFrames, 2))
+    heading   = np.zeros((nbFrames, 1))
+    angle     = np.zeros((nbFrames, 1))
+    allAngles = np.zeros((nbFrames, n))
+    tailX     = np.zeros((nbFrames, n))
+    tailY     = np.zeros((nbFrames, n))
     
     if hyperparameters["headingCalculationMethod"] == "calculatedWithMedianTailTip":
       tip2 = np.zeros((nbFrames, 2))
@@ -112,14 +147,27 @@ def extractParameters(trackingData, wellNumber, hyperparameters, videoPath, well
         heading[i] = calculateAngle(head[i], tail_1[i])
       elif hyperparameters["headingCalculationMethod"] == "calculatedWithMedianTailTip":
         heading[i] = calculateAngle(head[i], medianTip)
-      else: # calculatedWithHead
+      elif hyperparameters["headingCalculationMethod"] == "simplyFromPreviousCalculations":
         heading[i] = trackingHeading[i]
-        diff1 = distBetweenThetas(heading[i],           calculateAngle(head[i], tail_1[i]))
-        diff2 = distBetweenThetas(heading[i] + math.pi, calculateAngle(head[i], tail_1[i]))
-        if diff2 < diff1:
-          heading[i] = heading[i] + math.pi
+        heading[i] = (heading[i] + math.pi) % (2*math.pi)
+      else: # calculatedWithHead : THIS IS THE DEFAULT
+        if not(math.isnan(trackingHeading[i])):
+          heading[i] = trackingHeading[i]
+          diff1 = distBetweenThetas(heading[i],           calculateAngle(head[i], tail_1[i]))
+          diff2 = distBetweenThetas(heading[i] + math.pi, calculateAngle(head[i], tail_1[i]))
+          if diff2 < diff1:
+            heading[i] = heading[i] + math.pi
+        else:
+          heading[i] = 0
       
-      angle[i] = calculateTailAngle(calculateAngle(head[i], tip[i]), heading[i])
+      if type(tailAngle) == int:
+        angle[i] = calculateTailAngle(calculateAngle(head[i], tip[i]), heading[i])
+      else:
+        angle[i] = tailAngle[i]
+        
+      if hyperparameters["calculateAllTailAngles"]:
+        for j in range(0, n):
+          allAngles[i][j] = calculateTailAngle(calculateAngle(head[i], np.array([trackingTail[i][j][0], trackingTail[i][j][1]])), heading[i])
       
       heading[i] = (heading[i] + math.pi) % (2*math.pi)
       
@@ -256,11 +304,32 @@ def extractParameters(trackingData, wellNumber, hyperparameters, videoPath, well
       item["BoutStart"]     = start + firstFrame
       item["BoutEnd"]       = end + firstFrame
       item["TailAngle_Raw"] = angle[start:end+1,0].tolist()
-      item["HeadX"]         = head[start:end+1,0].tolist()
-      item["HeadY"]         = head[start:end+1,1].tolist()
-      item["Heading"]       = heading[start:end+1,0].tolist()
-      item["TailX_VideoReferential"] = tailX[start:end+1].tolist()
-      item["TailY_VideoReferential"] = tailY[start:end+1].tolist()
+      
+      if hyperparameters["eyeTracking"]:
+        item["leftEyeX"]      = trackingEyesAllAnimals[animalId, start:end+1, 0].tolist()
+        item["leftEyeY"]      = trackingEyesAllAnimals[animalId, start:end+1, 1].tolist()
+        item["leftEyeAngle"]  = trackingEyesAllAnimals[animalId, start:end+1, 2].tolist()
+        item["leftEyeArea"]   = trackingEyesAllAnimals[animalId, start:end+1, 3].tolist()
+        item["rightEyeX"]     = trackingEyesAllAnimals[animalId, start:end+1, 4].tolist()
+        item["rightEyeY"]     = trackingEyesAllAnimals[animalId, start:end+1, 5].tolist()
+        item["rightEyeAngle"] = trackingEyesAllAnimals[animalId, start:end+1, 6].tolist()
+        item["rightEyeArea"]  = trackingEyesAllAnimals[animalId, start:end+1, 7].tolist()
+      
+      [tailangles_arr, tailangles_arr_smoothed] = smoothAllTailAngles(allAngles, hyperparameters, start, end)
+      
+      if hyperparameters["calculateAllTailAngles"]:
+        item["allTailAngles"]         = tailangles_arr.tolist()
+        item["allTailAnglesSmoothed"] = tailangles_arr_smoothed.tolist()
+      
+      if np.isnan(head[start:end+1,0]).any():
+        item["HeadX"] = [0]
+        item["HeadY"] = [0]
+      else:
+        item["HeadX"]         = head[start:end+1,0].tolist()
+        item["HeadY"]         = head[start:end+1,1].tolist()
+        item["Heading"]       = heading[start:end+1,0].tolist()
+        item["TailX_VideoReferential"] = tailX[start:end+1].tolist()
+        item["TailY_VideoReferential"] = tailY[start:end+1].tolist()
       data.append(item)
   
   print("Parameters extracted for well",wellNumber)
