@@ -1,37 +1,60 @@
+from pathlib import Path
 import json
 import cv2
-from vars import getGlobalVariables
+import os
+from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
 
-with open("./code/defaultConfigFile.json") as f:
+cur_dir_path = os.path.dirname(os.path.realpath(__file__))
+
+cur_dir_path2 = Path(cur_dir_path)
+cur_dir_path2 = cur_dir_path2.parent
+
+with open(os.path.join(cur_dir_path, 'defaultConfigFile.json')) as f:
   configDefault = json.load(f)
 
 # Returns parameters in config file
 def getConfig(config, variableName, videoPath):
+  
   if variableName in config:
+    
     return config[variableName]
+    
   else:
+    
     if variableName in configDefault:
-      return configDefault[variableName]
-    else:
-      cap = cv2.VideoCapture(videoPath)
-      if (cap.isOpened()== False): 
-        print("Error opening video stream or file in getConfig")
-        return 0
-      if variableName == "firstFrame":
-        return 1
-      elif variableName == "lastFrame":
-        lastFrame = int(cap.get(cv2.CAP_PROP_FRAME_COUNT)) - 2
-        return lastFrame
-      elif variableName == "videoWidth":
-        frame_width  = int(cap.get(3))
-        return frame_width
-      elif variableName == "videoHeight":
-        frame_height = int(cap.get(4))
-        return frame_height
+      
+      if variableName == "outputFolder":
+        return os.path.join(cur_dir_path2, "ZZoutput")
       else:
-        print("You need to put the parameter",variableName,"in your configuration file")
-        return 0
+        return configDefault[variableName]
+        
+    else:
+      
+      cap = 0
+      if len(videoPath):
+        cap = cv2.VideoCapture(videoPath)
+      if (len(videoPath) == 0) or (cap.isOpened() == False):
+        print("Error opening video stream or file in getConfig")
+        if variableName == "firstFrame":
+          return 1
+        else:
+          return 0
+      else:
+        if variableName == "firstFrame":
+          return 1
+        elif variableName == "lastFrame":
+          lastFrame = int(cap.get(cv2.CAP_PROP_FRAME_COUNT)) - 2
+          return lastFrame
+        elif variableName == "videoWidth":
+          frame_width  = int(cap.get(3))
+          return frame_width
+        elif variableName == "videoHeight":
+          frame_height = int(cap.get(4))
+          return frame_height
+        else:
+          print("You need to put the parameter",variableName,"in your configuration file")
+          return 0
 
 def getHyperparameters(configFile, videoName, videoPath, argv):
 
@@ -147,6 +170,7 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["maxTailSize"] = getConfig(config, "maxTailSize", videoPath)
   
   hyperparameters["debugTrackingPtExtreme"] = getConfig(config, "debugTrackingPtExtreme", videoPath)
+  hyperparameters["debugTrackingPtExtremeLargeVerticals"] = getConfig(config, "debugTrackingPtExtremeLargeVerticals", videoPath)
   hyperparameters["debugTrackingThreshImg"] = getConfig(config, "debugTrackingThreshImg", videoPath)
 
   hyperparameters["erodeSize"]  = getConfig(config, "erodeSize", videoPath)
@@ -261,6 +285,54 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   
   hyperparameters["forceBlobMethodForHeadTracking"] = getConfig(config, "forceBlobMethodForHeadTracking", videoPath)
   
+  hyperparameters["headEmbededRetrackIfWeirdInitialTracking"] = getConfig(config, "headEmbededRetrackIfWeirdInitialTracking", videoPath)
+  
+  hyperparameters["overwriteHeadEmbededParamGaussianBlur"] = getConfig(config, "overwriteHeadEmbededParamGaussianBlur", videoPath)
+  
+  hyperparameters["calculateAllTailAngles"] = getConfig(config, "calculateAllTailAngles", videoPath)
+  
+  hyperparameters["nbPointsToIgnoreAtCurvatureBeginning"] = getConfig(config, "nbPointsToIgnoreAtCurvatureBeginning", videoPath)
+  
+  hyperparameters["nbPointsToIgnoreAtCurvatureEnd"] = getConfig(config, "nbPointsToIgnoreAtCurvatureEnd", videoPath)
+  
+  hyperparameters["imagePreProcessMethod"] = getConfig(config, "imagePreProcessMethod", videoPath)
+  hyperparameters["imagePreProcessParameters"] = getConfig(config, "imagePreProcessParameters", videoPath)
+  
+  hyperparameters["backgroundExtractionWithOnlyTwoFrames"] = getConfig(config, "backgroundExtractionWithOnlyTwoFrames", videoPath)
+  
+  hyperparameters["checkThatMovementOccurInVideo"] = getConfig(config, "checkThatMovementOccurInVideo", videoPath)
+  hyperparameters["checkThatMovementOccurInVideoMedianFilterWindow"] = getConfig(config, "checkThatMovementOccurInVideoMedianFilterWindow", videoPath)
+  
+  hyperparameters["findRectangleWellArea"] = getConfig(config, "findRectangleWellArea", videoPath)
+  hyperparameters["rectangleWellAreaImageThreshold"] = getConfig(config, "rectangleWellAreaImageThreshold", videoPath)
+  hyperparameters["rectangleWellErodeDilateKernelSize"] = getConfig(config, "rectangleWellErodeDilateKernelSize", videoPath)
+  hyperparameters["rectangularWellsInvertBlackWhite"] = getConfig(config, "rectangularWellsInvertBlackWhite", videoPath)
+  hyperparameters["rectangularWellStretchPercentage"] = getConfig(config, "rectangularWellStretchPercentage", videoPath)
+  hyperparameters["rectangleWellAreaTolerancePercentage"] = getConfig(config, "rectangleWellAreaTolerancePercentage", videoPath)
+
+  hyperparameters["adjustRectangularWellsDetect"] = getConfig(config, "adjustRectangularWellsDetect", videoPath)
+  
+  hyperparameters["outputValidationVideoFps"] = getConfig(config, "outputValidationVideoFps", videoPath)
+  
+  hyperparameters["checkAllContourForTailExtremityDetect"] = getConfig(config, "checkAllContourForTailExtremityDetect", videoPath)
+  hyperparameters["considerHighPointForTailExtremityDetect"] = getConfig(config, "considerHighPointForTailExtremityDetect", videoPath)
+  
+  hyperparameters["debugEyeTracking"]                   = getConfig(config, "debugEyeTracking", videoPath)
+  hyperparameters["debugEyeTrackingAdvanced"]           = getConfig(config, "debugEyeTrackingAdvanced", videoPath)
+  hyperparameters["eyeTracking"]                        = getConfig(config, "eyeTracking", videoPath)
+  hyperparameters["headCenterToMidEyesPointDistance"]   = getConfig(config, "headCenterToMidEyesPointDistance", videoPath)
+  hyperparameters["eyeBinaryThreshold"]                 = getConfig(config, "eyeBinaryThreshold", videoPath)
+  hyperparameters["midEyesPointToEyeCenterMaxDistance"] = getConfig(config, "midEyesPointToEyeCenterMaxDistance", videoPath)
+  hyperparameters["eyeHeadingSearchAreaHalfDiameter"]   = getConfig(config, "eyeHeadingSearchAreaHalfDiameter", videoPath)
+  hyperparameters["headingLineValidationPlotLength"]    = getConfig(config, "headingLineValidationPlotLength", videoPath)
+  hyperparameters["saveSuperStructToMatlab"]            = getConfig(config, "saveSuperStructToMatlab", videoPath)
+  hyperparameters["validationVideoPlotAnimalNumber"]    = getConfig(config, "validationVideoPlotAnimalNumber", videoPath)
+  hyperparameters["postProcessMultipleTrajectories"]    = getConfig(config, "postProcessMultipleTrajectories", videoPath)
+  hyperparameters["postProcessMaxDistanceAuthorized"]   = getConfig(config, "postProcessMaxDistanceAuthorized", videoPath)
+  hyperparameters["postProcessMaxDisapearanceFrames"]   = getConfig(config, "postProcessMaxDisapearanceFrames", videoPath)
+  hyperparameters["computeEyesHeadingPlot"]             = getConfig(config, "computeEyesHeadingPlot", videoPath)
+  hyperparameters["adjustMinPixelDiffForBackExtract_nbBlackPixelsMax"] = getConfig(config, "adjustMinPixelDiffForBackExtract_nbBlackPixelsMax", videoPath)
+  
   
   if len(argv) > 5 and not(argv[0] == "getTailExtremityFirstFrame"):
     i = 5
@@ -268,7 +340,11 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
       print("command line hyperparameter change:", argv[i], argv[i+1])
       
       if not(argv[i] in ["debugPauseBetweenTrackAndParamExtract", "outputFolder", "coverPortionForHeadDetect", "freeSwimmingTailTrackingMethod", "findContourPrecision", "headingCalculationMethod"]):
-        hyperparameters[argv[i]] = int(argv[i+1])
+        try:
+          hyperparameters[argv[i]] = int(argv[i+1])
+        except:
+          hyperparameters[argv[i]] = float(argv[i+1])
+        
       else:
         hyperparameters[argv[i]] = argv[i+1]
       
