@@ -1,9 +1,9 @@
 import cv2
 
-from headTrackingTakeHeadClosestToWellCenter import headTrackingTakeHeadClosestToWellCenter
-from calculateHeading import calculateHeading
-from multipleAnimalsHeadTracking import multipleAnimalsHeadTracking
-from multipleAnimalsHeadTrackingAdvance import multipleAnimalsHeadTrackingAdvance
+from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.headTrackingTakeHeadClosestToWellCenter import headTrackingTakeHeadClosestToWellCenter
+from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.calculateHeading import calculateHeading
+from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.multipleAnimalsHeadTracking import multipleAnimalsHeadTracking
+from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.multipleAnimalsHeadTrackingAdvance import multipleAnimalsHeadTrackingAdvance
 # from postProcessingMultiAnimalTrajectories import postProcessingMultiAnimalTrajectories
 
 def headTrackingHeadingCalculation(hyperparameters, firstFrame, i, blur, thresh1, thresh2, gray, erodeSize, frame_width, frame_height, trackingHeadingAllAnimals, trackingHeadTailAllAnimals, headPosition, lengthX):
