@@ -1,7 +1,7 @@
 import math
 import cv2
 import numpy as np
-from calculateHeading import calculateHeadingSimple
+from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.calculateHeading import calculateHeadingSimple, calculateHeading
 
 def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAnimals, hyperparameters, gray, i, firstFrame, thresh1, thresh3):
   
@@ -21,19 +21,14 @@ def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAn
   thresh2[:, len(thresh2[0])-1] = 255
   thresh2[len(thresh2)-1, :]    = 255
   
-  # print("frame:", i)
-  # cv2.imshow('Frame', thresh2)
-  # cv2.waitKey(0)
-  
   if hyperparameters["multipleHeadTrackingIterativelyRelaxAreaCriteria"]:
     contours, hierarchy = cv2.findContours(thresh2,cv2.RETR_TREE,cv2.CHAIN_APPROX_SIMPLE)
     while (len(headCoordinatesOptions) < hyperparameters["nbAnimalsPerWell"]) and (minAreaCur > 0):
       # print("MMMinAreaCur:", minAreaCur)
       for contour in contours:
         area = cv2.contourArea(contour)
-        # if area > 100:
-          # print("area:", area)
         if (area > minAreaCur) and (area < maxAreaCur):
+          # print("Find center of mass: area:", area)
           M = cv2.moments(contour)
           if M['m00']:
             x = int(M['m10']/M['m00'])
@@ -55,6 +50,7 @@ def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAn
     for contour in contours:
       area = cv2.contourArea(contour)
       if (area > minAreaCur) and (area < maxAreaCur):
+        # print("Find center of mass: area:", area)
         M = cv2.moments(contour)
         if M['m00']:
           x = int(M['m10']/M['m00'])
@@ -63,7 +59,7 @@ def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAn
           x = 0
           y = 0
         headCoordinatesOptions.append([x, y])
-      
+
   headCoordinatesOptionsAlreadyTakenDist     = [-1 for k in headCoordinatesOptions]
   headCoordinatesOptionsAlreadyTakenAnimalId = [-1 for k in headCoordinatesOptions]
   animalNotPutOrEjectedBecausePositionAlreadyTaken = 1
@@ -109,7 +105,6 @@ def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAn
                 headCoordinatesOptionsAlreadyTakenDist[index_min]     = min_dist
                 headCoordinatesOptionsAlreadyTakenAnimalId[index_min] = animal_Id               
   
-  
   headCoordinatesOptions = [headCoordinatesOptions[idx] for idx, k in enumerate(headCoordinatesOptionsAlreadyTakenAnimalId) if k == -1]
   
   for idxCoordinateOption, [idx_x_Option, idx_y_Option] in enumerate(headCoordinatesOptions):
@@ -125,6 +120,23 @@ def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAn
             trackingHeadTailAllAnimals[animal_Id, i-firstFrame][0][1] = idx_y_Option
             break
 
+  if hyperparameters["postProcessMultipleTrajectories"]:
+    maxDistanceAuthorized = hyperparameters["postProcessMaxDistanceAuthorized"]
+    maxDisapearanceFrames = hyperparameters["postProcessMaxDisapearanceFrames"]
+    for animal_Id in range(0, len(trackingHeadTailAllAnimals)):
+      goBackFrames = 1
+      xCur = trackingHeadTailAllAnimals[animal_Id, i-firstFrame][0][0]
+      yCur = trackingHeadTailAllAnimals[animal_Id, i-firstFrame][0][1]
+      if xCur != 0 or yCur != 0:
+        while (i-firstFrame-goBackFrames >= 0) and (goBackFrames < maxDisapearanceFrames) and (trackingHeadTailAllAnimals[animal_Id, i-firstFrame-goBackFrames][0][0] == 0) and (trackingHeadTailAllAnimals[animal_Id, i-firstFrame-goBackFrames][0][1] == 0):
+          goBackFrames = goBackFrames + 1
+        if (goBackFrames < maxDisapearanceFrames) and (i-firstFrame-goBackFrames >= 0):
+          xBef = trackingHeadTailAllAnimals[animal_Id, i-firstFrame-goBackFrames][0][0]
+          yBef = trackingHeadTailAllAnimals[animal_Id, i-firstFrame-goBackFrames][0][1]
+          if math.sqrt((xCur - xBef)**2 + (yCur - yBef)**2) > maxDistanceAuthorized:
+            trackingHeadTailAllAnimals[animal_Id, i-firstFrame][0][0] = 0
+            trackingHeadTailAllAnimals[animal_Id, i-firstFrame][0][1] = 0
+  
   
   # for idxCoordinateOption, [idx_x_Option, idx_y_Option] in enumerate(headCoordinatesOptions):
     # print(i, idxCoordinateOption, idx_x_Option, idx_y_Option)
@@ -176,7 +188,26 @@ def multipleAnimalsHeadTracking(trackingHeadingAllAnimals, trackingHeadTailAllAn
     if x_curFrame_animal_Id != 0 and y_curFrame_animal_Id != 0:
       x_curFrame_animal_Id = int(x_curFrame_animal_Id)
       y_curFrame_animal_Id = int(y_curFrame_animal_Id)
-      heading = calculateHeadingSimple(x_curFrame_animal_Id, y_curFrame_animal_Id, thresh2, hyperparameters)
+      
+      # Removing the other blobs from the image to get good heading detection
+      # Performance improvement possible below: TODO in the future
+      correspondingContour = 0
+      contours, hierarchy = cv2.findContours(thresh2,cv2.RETR_TREE,cv2.CHAIN_APPROX_SIMPLE)
+      for contour in contours:
+        dist = cv2.pointPolygonTest(contour, (x_curFrame_animal_Id, y_curFrame_animal_Id), True)
+        if dist >= 0:
+          correspondingContour = contour
+      thresh2bis = np.zeros((len(thresh2), len(thresh2[0])))
+      thresh2bis[:, :] = 255
+      if type(correspondingContour) != int:
+        cv2.fillPoly(thresh2bis, pts =[correspondingContour], color=(0, 0, 0))
+      
+      if hyperparameters["forceBlobMethodForHeadTracking"]: # Fish tracking, usually
+        previousFrameHeading = trackingHeadingAllAnimals[animal_Id, i-firstFrame-1] if i-firstFrame-1 > 0 else 0
+        [heading, lastFirstTheta] = calculateHeading(x_curFrame_animal_Id, y_curFrame_animal_Id, 0, thresh1, thresh2bis, 0, hyperparameters, previousFrameHeading)
+      else: # Drosophilia, mouse, and other center of mass only tracking
+        heading = calculateHeadingSimple(x_curFrame_animal_Id, y_curFrame_animal_Id, thresh2bis, hyperparameters)
+      
       trackingHeadingAllAnimals[animal_Id, i-firstFrame] = heading
   
   return [trackingHeadingAllAnimals, trackingHeadTailAllAnimals]
