@@ -2,12 +2,12 @@ import cv2
 import math
 import os
 
-from headEmbededTailTracking import headEmbededTailTracking
-from centerOfMassTailTracking import centerOfMassTailTracking
-from tailTrackingExtremityDetect import tailTrackingExtremityDetect
-from tailTrackingBlobDescent import tailTrackingBlobDescent
-from getTailTipManual import findHeadPositionByUserInput
-from headEmbededTailTrackingTeresaNicolson import headEmbededTailTrackingTeresaNicolson
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTracking import headEmbededTailTracking
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.centerOfMassTailTracking import centerOfMassTailTracking
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.tailTrackingExtremityDetect import tailTrackingExtremityDetect
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingBlobDescent import tailTrackingBlobDescent
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.getTailTipManual import findHeadPositionByUserInput
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTrackingTeresaNicolson import headEmbededTailTrackingTeresaNicolson
 
 def tailTracking(animalId, i, firstFrame, videoPath, frame, hyperparameters, thresh1, nbTailPoints, threshForBlackFrames, thetaDiffAccept, trackingHeadTailAllAnimals, trackingHeadingAllAnimals, lastFirstTheta, maxDepth, tailTip):
 
