@@ -4,19 +4,18 @@ import cv2
 import math
 import json
 import sys
-import matplotlib.pyplot as plt
 from scipy import interpolate
-from getForegroundImage import getForegroundImage
-from headEmbededFrame import headEmbededFrame
+from zebrazoom.code.getImage.getForegroundImage import getForegroundImage
+from zebrazoom.code.getImage.headEmbededFrame import headEmbededFrame
 from scipy.interpolate import UnivariateSpline
 from numpy import linspace
 
-from getMidline import getMidline
-from findTailExtremete import findTailExtremete
-from findTheTwoSides import findTheTwoSides
-from findBodyContour import findBodyContour
-from Rotate import Rotate
-from checkIfMidlineIsInBlob import checkIfMidlineIsInBlob
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.getMidline import getMidline
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.findTailExtremeteFolder.findTailExtremete import findTailExtremete
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.findTheTwoSides import findTheTwoSides
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.findBodyContour import findBodyContour
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.Rotate import Rotate
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.tailTrackingExtremityDetectFolder.findTailExtremeteFolder.checkIfMidlineIsInBlob import checkIfMidlineIsInBlob
 
 # from kalmanFilter import kalman_xy
 # from trackingFunctions import calculateAngle
@@ -32,7 +31,10 @@ def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugA
   lastFrame = hyperparameters["lastFrame"]
   
   if hyperparameters["debugTrackingThreshImg"]:
-    cv2.imshow('debugTrackingThreshImg', thresh1)
+    if hyperparameters["debugTrackingPtExtremeLargeVerticals"]:
+      cv2.imshow('debugTrackingThreshImg', thresh1[int(headPosition[1])-200:len(thresh1), :] )
+    else:
+      cv2.imshow('debugTrackingThreshImg', thresh1)
     cv2.waitKey(0)
   
   # Finding blob corresponding to the body of the fish
@@ -44,12 +46,9 @@ def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugA
     res = findTheTwoSides(headPosition, bodyContour, dst)
     
     # Finding tail extremity
-    # if True:
     rotatedContour = bodyContour.copy()
     rotatedContour = Rotate(rotatedContour,int(headPosition[0]),int(headPosition[1]),heading,dst)
-    [MostCurvyIndex, distance2] = findTailExtremete(rotatedContour, bodyContour, headPosition[0], int(res[0]), int(res[1]), debugAdv, dst, hyperparameters["tailExtremityMaxJugeDecreaseCoeff"])
-    # else:
-      # [MostCurvyIndex, distance2] = findTailExtremete(bodyContour, headPosition[0], int(res[0]), int(res[1]), debugAdv, dst)
+    [MostCurvyIndex, distance2] = findTailExtremete(rotatedContour, bodyContour, headPosition[0], int(res[0]), int(res[1]), debugAdv, dst, hyperparameters["tailExtremityMaxJugeDecreaseCoeff"], hyperparameters)
     
     if debugAdv:
       # Head Center
@@ -59,32 +58,35 @@ def tailTrackingExtremityDetect(headPosition,nbTailPoints,i,thresh1,frame,debugA
       cv2.circle(dst, (pt1[0],pt1[1]), 3, (255, 0, 0), -1)
       # Tail basis 2
       pt1 = bodyContour[int(res[1])][0]
-      cv2.circle(dst, (pt1[0],pt1[1]), 3, (255, 0, 0), -1)
+      cv2.circle(dst, (pt1[0],pt1[1]), 3, (180, 0, 0), -1)
       # Tail extremity
       pt1 = bodyContour[int(MostCurvyIndex)][0]
       cv2.circle(dst, (pt1[0],pt1[1]), 3, (0, 0, 255), -1)
+      #
+      if hyperparameters["debugTrackingPtExtremeLargeVerticals"]:
+        dst = dst[int(headPosition[1])-200:len(dst), :]
       # Plotting points
       cv2.imshow('Frame', dst)
       cv2.waitKey(0)
     
     # Getting Midline
-    taille = 10
-    tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters)
+    taille = nbTailPoints
+    tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
     
     # Optimizing midline if necessary
     midlineIsInBlobTrackingOptimization = hyperparameters["midlineIsInBlobTrackingOptimization"]
     if midlineIsInBlobTrackingOptimization:
-      [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters)
+      [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
       if allInside == False:
         n = len(bodyContour)
         maxTailLength = -1
         for j in range(0, n):
-          [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), j, bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters)
+          [allInside, tailLength] = checkIfMidlineIsInBlob(int(res[0]), int(res[1]), j, bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
           if allInside:
             if tailLength > maxTailLength:
               MostCurvyIndex = j
               maxTailLength = tailLength
-        tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters)        
+        tail = getMidline(int(res[0]), int(res[1]), int(MostCurvyIndex), bodyContour, dst, taille-1, distance2, debugAdv, hyperparameters, nbTailPoints)
     
     # Applying snake on tail
     applySnake = False
