@@ -1,26 +1,28 @@
 import h5py
 import numpy as np
 import cv2
-import popUpAlgoFollow
+from zebrazoom.code.popUpAlgoFollow import prepend
 import math
 import os
 
-from getImages import getImages
-from headTrackingHeadingCalculation import headTrackingHeadingCalculation
-from debugTracking import debugTracking
-from tailTracking import tailTracking
-from blackFramesDetection import getThresForBlackFrame, savingBlackFrames
-from getTailTipManual import getHeadPositionByFileSaved, findTailTipByUserInput, getTailTipByFileSaved, findHeadPositionByUserInput
+from zebrazoom.code.trackingFolder.getImages import getImages
+from zebrazoom.code.trackingFolder.headTrackingHeadingCalculationFolder.headTrackingHeadingCalculation import headTrackingHeadingCalculation
+from zebrazoom.code.trackingFolder.debugTracking import debugTracking
+from zebrazoom.code.trackingFolder.tailTracking import tailTracking
+from zebrazoom.code.trackingFolder.blackFramesDetection import getThresForBlackFrame, savingBlackFrames
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.getTailTipManual import getHeadPositionByFileSaved, findTailTipByUserInput, getTailTipByFileSaved, findHeadPositionByUserInput
+from zebrazoom.code.trackingFolder.eyeTracking.eyeTracking import eyeTracking
+from zebrazoom.code.trackingFolder.postProcessMultipleTrajectories import postProcessMultipleTrajectories
 
-from headEmbededFrame import headEmbededFrame
-from headEmbededFrameBackExtract import headEmbededFrameBackExtract
+from zebrazoom.code.getImage.headEmbededFrame import headEmbededFrame
+from zebrazoom.code.getImage.headEmbededFrameBackExtract import headEmbededFrameBackExtract
 
-from adjustHyperparameters import initializeAdjustHyperparametersWindows, adjustHyperparameters, getHeadEmbededTrackingParamsForHyperParamAdjusts, getFreelySwimTrackingParamsForHyperParamAdjusts
-from headEmbededTailTracking import adjustHeadEmbededHyperparameters
+from zebrazoom.code.adjustHyperparameters import initializeAdjustHyperparametersWindows, adjustHyperparameters, getHeadEmbededTrackingParamsForHyperParamAdjusts, getFreelySwimTrackingParamsForHyperParamAdjusts
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTracking import adjustHeadEmbededHyperparameters
 
-from headEmbededTailTracking import headEmbededTailTrackFindMaxDepth
-from headEmbededTailTrackingTeresaNicolson import headEmbededTailTrackFindMaxDepthTeresaNicolson, headEmbededTailTrackingTeresaNicolson
-from centerOfMassTailTracking import centerOfMassTailTrackFindMaxDepth
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTracking import headEmbededTailTrackFindMaxDepth
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.headEmbededTailTrackingTeresaNicolson import headEmbededTailTrackFindMaxDepthTeresaNicolson, headEmbededTailTrackingTeresaNicolson
+from zebrazoom.code.trackingFolder.tailTrackingFunctionsFolder.centerOfMassTailTracking import centerOfMassTailTrackFindMaxDepth
 
 def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters, videoName):
 
@@ -50,6 +52,10 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
     
   trackingHeadTailAllAnimals = np.zeros((hyperparameters["nbAnimalsPerWell"], lastFrame-firstFrame+1, nbTailPoints, 2))
   trackingHeadingAllAnimals = np.zeros((hyperparameters["nbAnimalsPerWell"], lastFrame-firstFrame+1))
+  if hyperparameters["eyeTracking"]:
+    trackingEyesAllAnimals = np.zeros((hyperparameters["nbAnimalsPerWell"], lastFrame-firstFrame+1, 8))
+  else:
+    trackingEyesAllAnimals = 0
   
   threshForBlackFrames = getThresForBlackFrame(hyperparameters, videoPath) # For headEmbededTeresaNicolson 
   cap.set(1, firstFrame)
@@ -57,30 +63,41 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
   # Using the first frame of the video to calculate parameters that will be used afterwards for the tracking
   if (hyperparameters["headEmbeded"] == 1):
     # Getting images
-    if hyperparameters["headEmbededRemoveBack"] == 0:
-      [frame, thresh1] = headEmbededFrame(videoPath, firstFrame)
+    
+    if hyperparameters["headEmbededRemoveBack"] == 0 and hyperparameters["headEmbededAutoSet_BackgroundExtractionOption"] == 0:
+      [frame, thresh1] = headEmbededFrame(videoPath, firstFrame, hyperparameters)
     else:
+      hyperparameters["headEmbededRemoveBack"] = 1
+      hyperparameters["minPixelDiffForBackExtract"] = hyperparameters["headEmbededAutoSet_BackgroundExtractionOption"]
       [frame, thresh1] = headEmbededFrameBackExtract(videoPath, background, hyperparameters, firstFrame)
+      
+    # if hyperparameters["invertBlackWhiteOnImages"]:
+      # frame   = 255 - frame
+    
     gray = frame.copy()
+    
     oppHeading = (heading + math.pi) % (2 * math.pi)
+    
     # Getting headPositionFirstFrame and tailTipFirstFrame positions
     if os.path.exists(videoPath+'HP.csv'):
       headPositionFirstFrame = getHeadPositionByFileSaved(videoPath)
     else:
       if hyperparameters["findHeadPositionByUserInput"]:
-        headPositionFirstFrame = findHeadPositionByUserInput(frame)
+        headPositionFirstFrame = findHeadPositionByUserInput(frame, firstFrame, videoPath)
       else:
         [frame, gray, thresh1, blur, thresh2, frame2] = getImages(hyperparameters, cap, videoPath, firstFrame, background, wellNumber, wellPositions)
         cap.set(1, firstFrame)
-        [trackingHeadingAllAnimals, trackingHeadTailAllAnimals, heading, lastFirstTheta] = headTrackingHeadingCalculation(hyperparameters, firstFrame, firstFrame, blur, thresh1, thresh2, gray, hyperparameters["erodeSize"], frame_width, frame_height, trackingHeadingAllAnimals, trackingHeadTailAllAnimals, headPositionFirstFrame, wellPositions[wellNumber]["lengthX"])
+        [trackingHeadingAllAnimals, trackingHeadTailAllAnimals, lastFirstTheta] = headTrackingHeadingCalculation(hyperparameters, firstFrame, firstFrame, blur, thresh1, thresh2, gray, hyperparameters["erodeSize"], frame_width, frame_height, trackingHeadingAllAnimals, trackingHeadTailAllAnimals, headPositionFirstFrame, wellPositions[wellNumber]["lengthX"])
     if os.path.exists(videoPath+'.csv'):
       tailTipFirstFrame  = getTailTipByFileSaved(hyperparameters,videoPath)
     else:
-      tailTipFirstFrame  = findTailTipByUserInput(frame,hyperparameters)
+      tailTipFirstFrame  = findTailTipByUserInput(frame, firstFrame, videoPath, hyperparameters)
     if hyperparameters["automaticallySetSomeOfTheHeadEmbededHyperparameters"] == 1:
       hyperparameters = adjustHeadEmbededHyperparameters(hyperparameters, frame, headPositionFirstFrame, tailTipFirstFrame)
     # Getting max depth
     if hyperparameters["headEmbededTeresaNicolson"] == 1:
+      if len(headPositionFirstFrame) == 0:
+        headPositionFirstFrame = [trackingHeadTailAllAnimals[0][0][0][0], trackingHeadTailAllAnimals[0][0][0][1]]
       maxDepth = headEmbededTailTrackFindMaxDepthTeresaNicolson(headPositionFirstFrame,nbTailPoints,firstFrame,headPositionFirstFrame[0],headPositionFirstFrame[1],thresh1,frame,hyperparameters,oppHeading,tailTipFirstFrame)
     else:
       if hyperparameters["centerOfMassTailTracking"] == 0:
@@ -99,7 +116,7 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
     if (hyperparameters["freqAlgoPosFollow"] != 0) and (i % hyperparameters["freqAlgoPosFollow"] == 0):
       print("Tracking: wellNumber:",wellNumber," ; frame:",i)
       if hyperparameters["popUpAlgoFollow"]:
-        popUpAlgoFollow.prepend("Tracking: wellNumber:" + str(wellNumber) + " ; frame:" + str(i))
+        prepend("Tracking: wellNumber:" + str(wellNumber) + " ; frame:" + str(i))
     if hyperparameters["debugTracking"]:
       print("frame:",i)
     # Get images for frame i
@@ -110,6 +127,9 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
     if hyperparameters["trackTail"] == 1 :
       for animalId in range(0, hyperparameters["nbAnimalsPerWell"]):
         trackingHeadTailAllAnimals = tailTracking(animalId, i, firstFrame, videoPath, frame, hyperparameters, thresh1, nbTailPoints, threshForBlackFrames, thetaDiffAccept, trackingHeadTailAllAnimals, trackingHeadingAllAnimals, lastFirstTheta, maxDepth, tailTipFirstFrame)
+    # Eye tracking for frame i
+    if hyperparameters["eyeTracking"]:
+      trackingEyesAllAnimals = eyeTracking(animalId, i, firstFrame, frame, hyperparameters, thresh1, trackingHeadingAllAnimals, trackingHeadTailAllAnimals, trackingEyesAllAnimals)
     
     # Debug functions
     debugTracking(nbTailPoints, i, firstFrame, trackingHeadTailAllAnimals, trackingHeadingAllAnimals, frame2, hyperparameters)
@@ -127,11 +147,14 @@ def tracking(videoPath, background, wellNumber, wellPositions, hyperparameters,
       [i, hyperparameters, organizationTabCur] = adjustHyperparameters(i, hyperparameters, hyperparametersListNames, frameToShow, WINDOW_NAME, organizationTabCur)
     else:
       i = i + 1
+      
+  if hyperparameters["postProcessMultipleTrajectories"]:
+    [trackingHeadingAllAnimals, trackingHeadTailAllAnimals, trackingEyesAllAnimals] = postProcessMultipleTrajectories(trackingHeadingAllAnimals, trackingHeadTailAllAnimals, trackingEyesAllAnimals, hyperparameters)
   
   savingBlackFrames(hyperparameters, videoName, trackingHeadTailAllAnimals)
   
   print("Tracking done for well", wellNumber)
   if hyperparameters["popUpAlgoFollow"]:
-    popUpAlgoFollow.prepend("Tracking done for well "+ str(wellNumber))
+    prepend("Tracking done for well "+ str(wellNumber))
   
-  return [trackingHeadTailAllAnimals, trackingHeadingAllAnimals, headPositionFirstFrame, tailTipFirstFrame]
+  return [trackingHeadTailAllAnimals, trackingHeadingAllAnimals, trackingEyesAllAnimals, headPositionFirstFrame, tailTipFirstFrame]
